@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0901';
+our $VERSION = '0.0902';
 
 use strict;
 use warnings;
@@ -203,10 +203,11 @@ sub set_time_sig {
 
 
 sub dura_size {
-    my ($duration) = @_;
+    my ($duration, $ppqn) = @_;
+    $ppqn ||= TICKS;
     my $size = 0;
     if ($duration =~ /^d(\d+)$/) {
-        $size = sprintf '%0.f', $1 / TICKS;
+        $size = sprintf '%0.f', $1 / $ppqn;
     }
     else {
         $size = $MIDI::Simple::Length{$duration};
@@ -228,7 +229,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0901
+version 0.0902
 
 =head1 SYNOPSIS
 
@@ -339,10 +340,14 @@ Set the B<score> C<time_signature> based on the given string.
 =head2 dura_size
 
   $size = dura_size($duration);
+  $size = dura_size($duration, $ppqn);
 
 Return the B<duration> size based on the L<MIDI::Simple> C<Length>
 value (e.g. C<hn>, C<ten>) or number of ticks (if given as C<d###>).
 
+If a B<ppqn> value is not given, we use the MIDI::Simple value of
+C<96> ticks.
+
 =head1 SEE ALSO
 
 The F<t/01-functions.t> test file in this distribution
